==> error_progress_button-0.2.0.tar.gz: lib/error_progress_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

class ErrorProgressButton extends StatelessWidget {
  Text buttonText = Text("Button");
  Color buttonColor = Colors.green;
  VoidCallback buttonOnPress;
  ErrorButtonState state = ErrorButtonState.normal;
  Text errorText = Text("");
  AlwaysStoppedAnimation<Color> progressColor = AlwaysStoppedAnimation<Color>(Colors.green);

  ErrorProgressButton({
    this.buttonText,
    this.buttonColor,
    @required this.buttonOnPress,
    @required this.state,
    this.errorText,
    this.progressColor
  });

  @override
  Widget build(BuildContext context) {
    return AnimatedCrossFade(
      alignment: Alignment.center,
      firstChild: AnimatedCrossFade(
        alignment: Alignment.center,
        firstChild: RaisedButton(
          color: buttonColor ?? Colors.green,
          onPressed: buttonOnPress,
          child: buttonText,
        ),
        secondChild: Container(
          alignment: Alignment.center,
          margin: EdgeInsets.all(8),
          child: CircularProgressIndicator(
            valueColor: progressColor,
          ),
        ),
        crossFadeState: state == ErrorButtonState.loading
            ? CrossFadeState.showSecond
            : CrossFadeState.showFirst,
        duration: Duration(milliseconds: 0),
      ),
      secondChild: Column(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          RaisedButton(
            color: buttonColor,
            onPressed: buttonOnPress,
            child: buttonText,
          ),
          errorText
        ],
      ),
      duration: Duration(milliseconds: 0),
      crossFadeState: state == ErrorButtonState.error
          ? CrossFadeState.showSecond
          : CrossFadeState.showFirst,
    );
  }
}

enum ErrorButtonState {
  normal,
  loading,
  error,
}

==> error_progress_button-0.2.1.tar.gz: lib/error_progress_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

class ErrorProgressButton extends StatelessWidget {
  Text buttonText = Text("Button");
  Color buttonColor = Colors.green;
  VoidCallback buttonOnPress;
  ErrorButtonState state = ErrorButtonState.normal;
  Text errorText = Text("");
  Animation<Color> progressColor = AlwaysStoppedAnimation<Color>(Colors.green);

  ErrorProgressButton({
    this.buttonText,
    this.buttonColor,
    @required this.buttonOnPress,
    @required this.state,
    this.errorText,
    this.progressColor
  });

  @override
  Widget build(BuildContext context) {
    return AnimatedCrossFade(
      alignment: Alignment.center,
      firstChild: AnimatedCrossFade(
        alignment: Alignment.center,
        firstChild: RaisedButton(
          color: buttonColor ?? Colors.green,
          onPressed: buttonOnPress,
          child: buttonText,
        ),
        secondChild: Container(
          alignment: Alignment.center,
          margin: EdgeInsets.all(8),
          child: CircularProgressIndicator(
            valueColor: progressColor,
          ),
        ),
        crossFadeState: state == ErrorButtonState.loading
            ? CrossFadeState.showSecond
            : CrossFadeState.showFirst,
        duration: Duration(milliseconds: 0),
      ),
      secondChild: Column(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          RaisedButton(
            color: buttonColor,
            onPressed: buttonOnPress,
            child: buttonText,
          ),
          errorText
        ],
      ),
      duration: Duration(milliseconds: 0),
      crossFadeState: state == ErrorButtonState.error
          ? CrossFadeState.showSecond
          : CrossFadeState.showFirst,
    );
  }
}

enum ErrorButtonState {
  normal,
  loading,
  error,
}
